/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.ri.servlet;

import java.io.Serializable;
import javax.servlet.http.HttpSession;
import org.jdtaus.core.container.Context;

/**
 * HTTP session {@code Context} implementation.
 * <p>This implementation needs to be configured manually for use by
 * {@link org.jdtaus.core.container.ContextFactory#newContext()}. See the
 * factory for how to configure this class to be used.</p>
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: HttpSessionContext.java 3553 2007-05-25 22:37:09Z schulte2005 $
 *
 * @see ServletFilter
 */
public class HttpSessionContext implements Context
{
    //--Context-----------------------------------------------------------------

    public Object getAttribute(final String key)
    {
        if(key == null)
        {
            throw new NullPointerException("key");
        }

        return this.getSession().getAttribute(key);
    }

    public Object setAttribute(final String key, final Serializable value)
    {

        if(key == null)
        {
            throw new NullPointerException("key");
        }

        final Object old = this.getSession().getAttribute(key);
        this.getSession().setAttribute(key, value);

        return old;
    }

    public Object removeAttribute(String key)
    {
        if(key == null)
        {
            throw new NullPointerException("key");
        }

        final Object old = this.getSession().getAttribute(key);
        this.getSession().removeAttribute(key);

        return old;
    }

    /** @see ServletFilter#getHttpSession() */
    public HttpSession getSession()
    {
        return ServletFilter.getHttpSession();
    }

    //-----------------------------------------------------------------Context--
}
